
# Class: class_level_rule


A rule that is applied to classes

URI: [linkml:ClassLevelRule](https://w3id.org/linkml/ClassLevelRule)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[ClassRule],[ClassLevelRule]^-[ClassRule])](https://yuml.me/diagram/nofunky;dir:TB/class/[ClassRule],[ClassLevelRule]^-[ClassRule])

## Children

 * [ClassRule](ClassRule.md) - A rule that applies to instances of a class

## Referenced by Class


## Attributes

